from django.apps import AppConfig


class AuthConfig(AppConfig):
    name = 'st_common_data.auth'
    label = 'auth0'
